gwo.websiteoptimizer.data — django-gwo v0.1 documentation

django-gwo v0.1 documentation

# gwo.websiteoptimizer.data

- Table of Contents
- index
  modules
  previous

# gwo.websiteoptimizer.data

class `AnalyticsAccountId`(text=None, *args, **kwargs)

  the account ID that owns this experiment. (read-only; may be set during experiment creation)

class `AutoPruneMode`(text=None, *args, **kwargs)

  the auto-prune setting for this experiment: None, Conservative, Normal or Aggressive.

class `BaseGWOElement`(text=None, *args, **kwargs)

  Base class that sets the metaclass

class `CombinationEntry`(atom_id=None, text=None, *args, **kwargs)

  A combination in the specified experiment

  `combo_active`

    alias of `ComboActive`

  `combo_id`

    alias of `ComboId`

  `combo_string`

    alias of `ComboString`

  `experiment_id`

    alias of `ExperimentId`

  `id`

    alias of `Id`

class `CombinationFeed`(atom_id=None, text=None, *args, **kwargs)

  A list of all combinations in the specified experiment

class `ComboActive`(text=None, *args, **kwargs)

  true if the combination is active; false if it has been pruned.

class `ComboId`(text=None, *args, **kwargs)

  the id of this combination (0-based; read-only)

class `ComboString`(text=None, *args, **kwargs)

  the combination info string, which consists of a set of variation indices for each section. For example, 0-1-1. (read-only)

class `ControlScript`(text=None, *args, **kwargs)

  the control script that should be placed at the top of any webpage in this experiment. (read-only)

class `ConversionScript`(text=None, *args, **kwargs)

  the conversion script that should be called when a visitor converts. (read-only)

class `Coverage`(text=None, *args, **kwargs)

  the percentage of total traffic to include in the experiment.

class `ExperimentEntry`(atom_id=None, text=None, *args, **kwargs)

  An experiment on Google Website Optimizer

  `analytics_account_id`

    alias of `AnalyticsAccountId`

  `auto_prune_mode`

    alias of `AutoPruneMode`

  `control_script`

    alias of `ControlScript`

  `conversion_script`

    alias of `ConversionScript`

  `coverage`

    alias of `Coverage`

  `experiment_id`

    alias of `ExperimentId`

  `experiment_notes`

    alias of `ExperimentNotes`

  `experiment_type`

    alias of `ExperimentType`

  `id`

    alias of `Id`

  `num_ab_page_variations`

    alias of `NumAbPageVariations`

  `num_combinations`

    alias of `NumCombinations`

  `num_sections`

    alias of `NumSections`

  `source_experiment_id`

    alias of `SourceExperimentId`

  `status`

    alias of `Status`

  `title`

    alias of `Title`

  `tracking_script`

    alias of `TrackingScript`

  `update_goal_link`(url)

    Convenience function for changing the goalUrl

    Parameters: | url (str) – The new goal URL

  `update_test_link`(url)

    Convenience method for changing the testUrl

    Parameters: | url (str) – The new testing URL

  `verification_combo`

    alias of `VerificationCombo`

  `verification_combo_coverage`

    alias of `VerificationComboCoverage`

class `ExperimentFeed`(atom_id=None, text=None, *args, **kwargs)

  Web Optimizer Experiments Feed <feed>

class `ExperimentId`(text=None, *args, **kwargs)

  the experiment ID for this experiment (read-only)

class `ExperimentNotes`(text=None, *args, **kwargs)

  user-created notes field. Limited to 2000 characters.

class `ExperimentType`(text=None, *args, **kwargs)

  the experiment type: AB or Multivariate. (read-only; may be set during experiment creation)

class `GWOElementClass`

  A metaclass that sets the _qname attribute based on the class name

class `GwoLink`(*args, **kwargs)

  A link with the gwo namespace

class `GwoLinkFinder`

  Locates the various links within the ExperimentsEntry

  `get_configuration_url`()

    the link to the configuration page for the experiment. (read-only)

  `get_goal_link`()

    the goal page url (as entered by user) for display in Website Optimizer UI.

  `get_report_url`()

    the link to the report page for the experiment. (read-only)

  `get_test_link`()

    the test page URL (as entered by the user) for display in Website Optimizer UI.

class `NumAbPageVariations`(text=None, *args, **kwargs)

  the number of page variations in this experiment (A/B experiments only). (read-only)

class `NumCombinations`(text=None, *args, **kwargs)

  the number of combinations in the experiment. (read-only)

class `NumSections`(text=None, *args, **kwargs)

  the number of sections in the experiment (multivariate experiments only). (read-only)

class `NumVariations`(text=None, *args, **kwargs)

  the number of variations for this section. (read-only)

class `SectionBeginScript`(text=None, *args, **kwargs)

  the script snippet to place before this section. (read-only)

class `SectionEndScript`(text=None, *args, **kwargs)

  the script snippet to place after this section (read-only)

class `SectionEntry`(atom_id=None, text=None, *args, **kwargs)
  `experiment_id`

    alias of `ExperimentId`

  `id`

    alias of `Id`

  `num_variations`

    alias of `NumVariations`

  `section_begin_script`

    alias of `SectionBeginScript`

  `section_end_script`

    alias of `SectionEndScript`

  `section_id`

    alias of `SectionId`

  `title`

    alias of `Title`

class `SectionFeed`(atom_id=None, text=None, *args, **kwargs)

  All of the sections for a multivariate experiment

class `SectionId`(text=None, *args, **kwargs)

  the id for this section (0-based). (read-only)

class `SourceExperimentId`(text=None, *args, **kwargs)

  the experiment ID of which this experiment is a copy or follow-up. (read-only; may be set during experiment creation)

class `Status`(text=None, *args, **kwargs)

  the current status of the experiment: New, Running, Paused, or Finished.

class `TrackingScript`(text=None, *args, **kwargs)

  the tracking script that should be placed at the bottom of any webpage in this experiment. (read-only)

class `VariationEntry`(atom_id=None, text=None, *args, **kwargs)

  A variation for a specific section of a specific experiment

  `content`

    alias of `Content`

  `experiment_id`

    alias of `ExperimentId`

  `id`

    alias of `Id`

  `section_id`

    alias of `SectionId`

  `variation_id`

    alias of `VariationId`

class `VariationFeed`(atom_id=None, text=None, *args, **kwargs)

  All the variations for a specific section of a specific experiment

class `VariationId`(text=None, *args, **kwargs)

  the id for this variation (0-based). (read-only)

class `VerificationCombo`(text=None, *args, **kwargs)

  for follow-up experiments, the combination being verified against the original. (read-only; may be set during experiment creation)

class `VerificationComboCoverage`(text=None, *args, **kwargs)

  for follow-up experiments, the percentage of traffic to send to the verification combo. (read-only, may be set during experiment creation)